package
Version:
v0.0.0-...-2c46ed6
Opens a new window with list of versions in this module.
Published: Mar 16, 2019
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Optimizer interface {
Add(layer int, cost, activation *tensor.Vector)
Init(deltas *[][]int)
Optimizations() *[][][]float64
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.